@@ -47,10 +47,9 @@ class CapellaConsoleClient:
         verbose: flag to enable verbose logging
         no_token_check: does not check if provided JWT token is valid
 
-    Note:
-
-    * not providing either email and password or a jwt token for authentication
-      will prompt you for email and password, which is not what you want in a script
+    NOTE:
+        not providing either email and password or a jwt token for authentication
+        will prompt you for email and password, which is not what you want in a script
 
     NOTE: Precedence order (high to low)
         1. email and password
@@ -229,6 +228,7 @@ class CapellaConsoleClient:
         items: Optional[List[Dict[str, Any]]] = None,
         check_active_orders: bool = False,
         omit_search: bool = False,
+        omit_review: bool = False,
     ) -> str:
         """
         submit an order by `stac_ids` or `items`.
@@ -244,6 +244,7 @@ class CapellaConsoleClient:
                 if True: returns that order ID
                 if False: submits a new order and returns new order ID
             omit_search: omit search to ensure provided STAC IDs are valid - only works if `items` are provided
+            omit_review: omit review stage
             Returns:
                 str: order UUID
         """
@@ -255,7 +256,6 @@ class CapellaConsoleClient:
                 logger.info(f"found active order {order_id}")
                 return order_id
 
-        logger.info(f"submitting order for {', '.join(stac_ids)}")
         if stac_ids and not omit_search:
             stac_items = self.search(ids=stac_ids)
         else:
@@ -268,8 +268,10 @@ class CapellaConsoleClient:
         if not stac_items:
             raise NoValidStacIdsError(f"No valid STAC IDs in {', '.join(stac_ids)}")
 
-        self.review_order(items=stac_items)
+        if not omit_review:
+            self.review_order(items=stac_items)
 
+        logger.info(f"submitting order for {', '.join(stac_ids)}")
         order_payload = self._construct_order_payload(stac_items)
 
         # perform actual order
